@@ -693,7 +693,14 @@ eog_image_apply_display_profile (EogImage *img, cmsHPROFILE screen)
 
 	priv = img->priv;
 
-	if (screen == NULL || priv->profile == NULL) return;
+	if (screen == NULL) return;
+
+	if (priv->profile == NULL) {
+		/* Assume sRGB color space for images without ICC profile */
+		eog_debug_message (DEBUG_LCMS, "Image has no ICC profile. "
+		                   "Assuming sRGB.");
+		priv->profile = cmsCreate_sRGBProfile ();
+	}
 
 	/* TODO: support other colorspaces than RGB */
 	if (cmsGetColorSpace (priv->profile) != cmsSigRgbData ||
@@ -702,18 +709,17 @@ eog_image_apply_display_profile (EogImage *img, cmsHPROFILE screen)
 		return;
 	}
 
-	/* TODO: find the right way to colorcorrect RGBA images */
-	if (gdk_pixbuf_get_has_alpha (priv->image)) {
-		eog_debug_message (DEBUG_LCMS, "Colorcorrecting RGBA images is unsupported.");
-		return;
-	}
+	cmsUInt32Number color_type = TYPE_RGB_8;
+
+	if (gdk_pixbuf_get_has_alpha (priv->image))
+		color_type = TYPE_RGBA_8;
 
 	transform = cmsCreateTransform (priv->profile,
-				        TYPE_RGB_8,
-				        screen,
-				        TYPE_RGB_8,
-				        INTENT_PERCEPTUAL,
-				        0);
+	                                color_type,
+	                                screen,
+	                                color_type,
+	                                INTENT_PERCEPTUAL,
+	                                0);
 
 	if (G_LIKELY (transform != NULL)) {
 		rows = gdk_pixbuf_get_height (priv->image);
